@@ -10,13 +10,13 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 ################################################################
 class SQLEngine():
 
-    def __init__(self, loadfile='src/swagenttools/sql_functions/swagent_main_db_create.sql'):
+    def __init__(self, loadfile='sql_functions/swagent_main_db_create.sql'):
         self.engine = None
-        self.filename = loadfile
+        self.filepath = os.path.join(os.path.dirname(os.path.abspath(__file__)), loadfile)
 
         # extract the functions found in the file passed.
         self.sql_functions = {}
-        with open(loadfile, 'r') as f:
+        with open(loadpath, 'r') as f:
             r = list(filter(None, f.read().split("\n--")))
             for rr in r:
                 sql_func_name = rr.split('\n', 1)[0]
